{#
.. screenshot:: |canaille|/groups
   :context: admin
   :align: right
   :width: 275px

   The group list page.

The group list page.

:param table: A :class:`~canaille.core.models.Group` pagination form.
:type table: :class:`~canaille.app.forms.TableForm`
#}
{% extends theme('base.html') %}
{% import "macro/table.html" as table %}

{%- block title -%}
    {% trans %}Groups{% endtrans %}
{%- endblock -%}

{% block submenu %}
    <a class="active item" href="{{ url_for('core.groups.groups') }}">
        <i class="th list icon"></i>
        {% trans %}View{% endtrans %}
    </a>
    <a class="item" href="{{ url_for('core.groups.create_group') }}">
        <i class="plus icon"></i>
        {% trans %}Add{% endtrans %}
    </a>
{% endblock %}

{% block content %}
    <div class="ui top attached segment">
        <h2 class="ui center aligned header">
            <div class="content">
                {% trans %}Groups{% endtrans %}
            </div>
        </h2>
        {{ table.search(table_form, "table.groups") }}
    </div>
    {% include "core/partial/groups.html" %}
{% endblock %}
